faker\_file.providers.mp3\_file package
=======================================

Subpackages
-----------

.. toctree::
   :maxdepth: 20

   faker_file.providers.mp3_file.generators

Module contents
---------------

.. automodule:: faker_file.providers.mp3_file
   :members:
   :undoc-members:
   :show-inheritance:
